GuessIt — GuessIt 0.8.dev0 documentation

### Navigation

- index
- modules |
- next |
- GuessIt 0.8.dev0 documentation »

# GuessIt

Release v0.8.dev0 (Installation)

GuessIt is a python library that tries to extract as much information as possible from a video file.

It has a powerful filename matcher that allows to guess a lot of metadata from a video using only its filename. This matcher works with both movies and tv shows episodes.

For example, GuessIt can do the following:

    $ python guessit.py "Treme.1x03.Right.Place,.Wrong.Time.HDTV.XviD-NoTV.avi"
    For: Treme.1x03.Right.Place,.Wrong.Time.HDTV.XviD-NoTV.avi
    GuessIt found: {
        [1.00] "mimetype": "video/x-msvideo",
        [0.80] "episodeNumber": 3,
        [0.80] "videoCodec": "XviD",
        [1.00] "container": "avi",
        [1.00] "format": "HDTV",
        [0.70] "series": "Treme",
        [0.50] "title": "Right Place, Wrong Time",
        [0.80] "releaseGroup": "NoTV",
        [0.80] "season": 1,
        [1.00] "type": "episode"
    }

## Features

At the moment, the filename matcher is able to recognize the following property types:

    [ title,                             # for movies and episodes
      series, season, episodeNumber,     # for episodes only
      date, year,                        # 'date' instance of datetime.date
      language, subtitleLanguage,        # instances of guessit.Language
      country,                           # instances of guessit.Country
      container, format,
      videoCodec, audioCodec,
      audioChannels, screenSize,
      releaseGroup, website,
      cdNumber, cdNumberTotal,
      filmNumber, filmSeries,
      bonusNumber, edition,
      idNumber,                          # tries to identify a hash or a serial number
      other
      ]

Guessit also allows you to compute a whole lof of hashes from a file, namely all the ones you can find in the hashlib python module (md5, sha1, ...), but also the Media Player Classic hash that is used (amongst others) by OpenSubtitles and SMPlayer, as well as the ed2k hash.

If you have the ‘guess-language’ python module installed, GuessIt can also analyze a subtitle file’s contents and detect which language it is written in.

## User Guide

This part of the documentation, which is mostly prose, shows how to use Guessit both from the command-line and as a python module which you can use in your own projects.

- Installation
  - Distribute & Pip
  - Get the Code
- Command-line usage
- Python module usage

## Developer Guide

If you want to contribute to the project, this part of the documentation is for you.

- Understanding the MatchTree
- What does the IterativeMatcher do?
  - Splitting into path components
  - Splitting into explicit groups
  - Finding interesting patterns
  - Using positional rules to find the ‘title’ property
- Merging all the results in a MatchTree to give a final Guess

You may also want to familiarize yourself with the following classes:

- Guess
- MatchTree
- Matchers

## Support

The project website for GuessIt is hosted at ReadTheDocs. There you will also find the User guide and Developer documentation.

This project is hosted on GitHub: https://github.com/wackou/guessit

Please report issues and/or feature requests via the bug tracker.

## Contribute

GuessIt is under active development, and contributions are more than welcome!

1. Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug. There is a Contributor Friendly tag for issues that should be ideal for people who are not very familiar with the codebase yet.
2. Fork the repository on Github to start making your changes to the master branch (or branch off of it).
3. Write a test which shows that the bug was fixed or that the feature works as expected.
4. Send a pull request and bug the maintainer until it gets merged and published. :)

## License

GuessIt is licensed under the LGPLV3 license.